searchData={"content_type":"text/markdown","items":[{"doc":"Automatically generate api specs for your typed structs. This library is a plugin for [OpenApiSpex](github.com/open-api-spex/open_api_spex) that allows you to define typed structs and have the schema automatically generated for you. You can then easily reference these schemas in your OpenApiSpex operations. This allows you to keep your api specs in sync with your typed structs without having to constantly update two different versions of what is effectively the same schema.\n\n- Give your struct a title and you're all set, the rest is generated for you.\n- You can optionally give `default` values to your fields and they will also be included in the schema.\n- Same for `example`s. Can be combined with default values.\n- Additionally, you can override the generated schema property for specific fields by providing a\n  `property` option to the field. This is for when you want to reference another schema.","ref":"OpenApiSpexTypedStruct.html","title":"OpenApiSpexTypedStruct","type":"module"},{"doc":"```elixir\ndefmodule MySpec do\n  use TypedStruct\n\n  typedstruct do\n    plugin TypedSpec, title: \"my spec\"\n    field :id, :string, default: \"123\", example: \"456\"\n    field :qty, :integer\n    field :other_schema, :object, property: MyOtherSchema\n  end\nend\n```\n\nGenerates a schema that looks like:\n```elixir\n%OpenApiSpex.Schema%{\n  properties: %{\n    id: %OpenApiSpex.Schema%{type: :string, default: \"123\", example: \"456\"},\n    qty: %OpenApiSpex.Schema%{type: :integer},\n    other_schema: OtherSchema\n  },\n  required: [:id, :qty],\n  title: \"my spec\",\n  type: :object\n}\n```\n\nThat can then be used with OpenApiSpex in your controller:\n```elixir\noperation(:index,\n  summary: \"Get fancy new spec-ed things\",\n  responses: [\n    ok: {\"Successful\", \"application/json\", MySpec},\n  ]\n)\n```","ref":"OpenApiSpexTypedStruct.html#module-usage","title":"Usage - OpenApiSpexTypedStruct","type":"module"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}